# Dapla Toolbelt Metadata

[![PyPI](https://img.shields.io/pypi/v/dapla-toolbelt-metadata.svg)][pypi status]
[![Status](https://img.shields.io/pypi/status/dapla-toolbelt-metadata.svg)][pypi status]
[![Python Version](https://img.shields.io/pypi/pyversions/dapla-toolbelt-metadata)][pypi status]
[![License](https://img.shields.io/pypi/l/dapla-toolbelt-metadata)][license]

[![Documentation](https://github.com/statisticsnorway/dapla-toolbelt-metadata/actions/workflows/docs.yml/badge.svg)][documentation]
[![Tests](https://github.com/statisticsnorway/dapla-toolbelt-metadata/actions/workflows/tests.yml/badge.svg)][tests]
[![Coverage](https://sonarcloud.io/api/project_badges/measure?project=statisticsnorway_dapla-toolbelt-metadata&metric=coverage&token=ee0a4d273db2bf811222fca5dffccd4592e3d536)][sonarcov]
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=statisticsnorway_dapla-toolbelt-metadata&metric=alert_status&token=ee0a4d273db2bf811222fca5dffccd4592e3d536)][sonarquality]

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)][uv]

[pypi status]: https://pypi.org/project/dapla-toolbelt-metadata/
[documentation]: https://statisticsnorway.github.io/dapla-toolbelt-metadata
[tests]: https://github.com/statisticsnorway/dapla-toolbelt-metadata/actions?workflow=Tests
[sonarcov]: https://sonarcloud.io/summary/overall?id=statisticsnorway_dapla-toolbelt-metadata
[sonarquality]: https://sonarcloud.io/summary/overall?id=statisticsnorway_dapla-toolbelt-metadata
[pre-commit]: https://github.com/pre-commit/pre-commit
[uv]: https://docs.astral.sh/uv/

Tools and clients for working with the Dapla Metadata system.

## Features

- Create and update metadata for datasets (aka Datadoc).
- Read, create and update variable definitions (aka Vardef).
- Check compliance with SSBs naming standard.

### Coming

- Publish dataset metadata to Statistics Norway's data catalogue.
- Maintain classifications and code lists.

## Installation

You can install _Dapla Toolbelt Metadata_ via [pip] from [PyPI]:

```console
pip install dapla-toolbelt-metadata
```

## Usage

Instructions and examples may be found in the [Dapla Manual](https://manual.dapla.ssb.no/statistikkere/). Please see the [Reference Guide] for API documentation.

## Contributing

Contributions are very welcome.
To learn more, see the [Contributor Guide].

## License

Distributed under the terms of the [MIT license][license],
_Dapla Toolbelt Metadata_ is free and open source software.

## Issues

If you encounter any problems,
please [file an issue] along with a detailed description.

## Credits

This project was generated from [Statistics Norway]'s [SSB PyPI Template].

[statistics norway]: https://www.ssb.no/en
[pypi]: https://pypi.org/
[ssb pypi template]: https://github.com/statisticsnorway/ssb-pypitemplate
[file an issue]: https://github.com/statisticsnorway/dapla-toolbelt-metadata/issues
[pip]: https://pip.pypa.io/

<!-- github-only -->

[license]: https://github.com/statisticsnorway/dapla-toolbelt-metadata/blob/main/LICENSE
[contributor guide]: https://github.com/statisticsnorway/dapla-toolbelt-metadata/blob/main/CONTRIBUTING.md
[reference guide]: https://statisticsnorway.github.io/dapla-toolbelt-metadata/dapla_metadata.html
